#
# spec file for package scidavis
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Quentin Denis <quentin@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           scidavis
Version:        1.22
Release:        lp152.2.8
Summary:        An application for Scientific Data Analysis and Visualization
License:        GPL-2.0-only AND GPL-3.0-or-later
Group:          Productivity/Scientific/Math
Url:            http://scidavis.sourceforge.net/
Source0:        http://downloads.sourceforge.net/project/scidavis/SciDAVis/%{version}/scidavis-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  Mesa-devel
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  fontconfig
BuildRequires:  gsl
BuildRequires:  gsl-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  kde4-filesystem
BuildRequires:  liborigin-devel
BuildRequires:  libqt4-devel
BuildRequires:  libqt4-devel-doc
BuildRequires:  libstdc++-devel
BuildRequires:  muparser-devel
BuildRequires:  python-devel
BuildRequires:  python-qt4
BuildRequires:  python-qt4-devel
BuildRequires:  qt4-assistant-adp-devel
BuildRequires:  qwt-devel
BuildRequires:  qwtplot3d-devel
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
%if 0%{?suse_version} > 1220
BuildRequires:  glu-devel
%endif

%description
SciDAVis is an interactive application for data analysis and
publication-quality plotting. It has scriptability and can be extended.

SciDAVis is similar in its field of application to proprietary Windows
applications like Origin and SigmaPlot as well as free applications like
QtiPlot, Labplot and Gnuplot.

%prep
%setup -q

# Fix files is compiled without RPM_OPT_FLAG
find . -type f -name \*.pro | while read FILE; do
echo "QMAKE_CFLAGS += %{optflags}" >> "$FILE"
echo "QMAKE_CXXFLAGS += %{optflags}" >> "$FILE"; done

%build
export PATH=$QTDIR/bin:$PATH
%ifarch x86_64 ppc64 ppc64le
export QMAKESPEC="linux-g++-64"
%endif
%ifarch aarch64
# aarch64 uses QMAKESPEC="linux-g++" but will install in lib64
sed -i "s/linux-g++-64: libsuff = 64/libsuff = 64/g" config.pri
%endif
qmake %{name}.pro QMAKE_CFLAGS+="%optflags" QMAKE_CXXFLAGS+="%optflags" QMAKE_STRIP="/bin/true";
make %{?_smp_mflags}

%install
make INSTALL_ROOT=%{buildroot} install

# https://github.com/highperformancecoder/scidavis/issues/48
mkdir -p %{buildroot}%{_datadir}/%{name}/translations
cp %{name}/translations/%{name}_*.qm %{buildroot}%{_datadir}/%{name}/translations/
%find_lang %{name} --with-qt

# Remove unneeded files.
rm -rf %{buildroot}%{_datadir}/doc/%{name}

%post
%desktop_database_post
%icon_theme_cache_post
%mime_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun

%files -f %{name}.lang
%doc CHANGES README.md gpl.txt LICENSE
%{_bindir}/%{name}
%{_libdir}/%{name}
%{_datadir}/%{name}
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/mimelnk
%dir %{_datadir}/mimelnk/application/
%{_datadir}/mimelnk/application/x-sciprj.desktop
%{_mandir}/man1/%{name}.1*
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%dir %{_datadir}/icons/locolor
%dir %{_datadir}/icons/locolor/16x16
%dir %{_datadir}/icons/locolor/16x16/apps
%{_datadir}/icons/locolor/16x16/apps/scidavis.png
%dir %{_datadir}/icons/locolor/22x22
%dir %{_datadir}/icons/locolor/22x22/apps
%{_datadir}/icons/locolor/22x22/apps/scidavis.png
%dir %{_datadir}/icons/locolor/32x32
%dir %{_datadir}/icons/locolor/32x32/apps
%{_datadir}/icons/locolor/32x32/apps/scidavis.png
%{_datadir}/mime/packages/scidavis.xml

%changelog
* Wed Apr 18 2018 guillaume.gardet@opensuse.org
- Handle aarch64 arch
- Make use of optflags
* Wed Nov  1 2017 ronisbr@gmail.com
- Update to version 1.22.
- Run spec-cleaner.
* Sat Aug 12 2017 aloisio@gmx.com
- Update to version 1.21
- Dropped man.patch (merged upstream)
* Sun Aug  6 2017 mailaender@opensuse.org
- Update to 1.19
- Add man.patch to solve man page installation properly
* Tue Aug  9 2016 ronisbr@gmail.com
- Update to 1.14.
  * No changelog available.
- Remove unneeded patch (solved by upstream):
  * scidavis-tableitem.patch
* Wed Jun 29 2016 ronisbr@gmail.com
- Update to 1.D13.
  * No changelog available
- Add patch `scidavis-tableitem.patch` to fix compilation with
  GCC6.
- Remove unneeded patch (solved by upstream):
  * scidavis.1.D9_correct_return.patch
* Tue Dec 22 2015 ronisbr@gmail.com
- Update to 1.D9.
  * No changelog available.
- Remove _service.
- Remove patches (solved by upstream):
  * scidavis.1.D8_comment_python.patch;
  * scidavis.1.D8_graph_const.patch;
  * scidavis.1.D8_not_orig_liborigin.patch;
  * scidavis.1.D8_ts.patch.
- Update patch to version 1.D9:
  * scidavis.1.D9_correct_return.patch.
- Run spec-cleaner.
- Minor fixes in .spec.
* Wed May  6 2015 avvissu@yandex.ru
- Fix files is compiled without RPM_OPT_FLAG
- Update the system MIME cache:
  * add %%mime_database_{post,postun} %%desktop_database__{post,postun}
- Fix error found by RPMlint: directories not owned by a package:
  * add BuildRequires: kde4-filesystem
* Wed Nov  5 2014 avvissu@yandex.ru
- Fix path of translations (scidavis.1.D8_ts.patch)
* Mon Nov  3 2014 avvissu@yandex.ru
- Add Python expressions and scripts:
  - add BuildRequires: python-devel python-qt4 python-qt4-devel
* Wed Oct 29 2014 avvissu@yandex.ru
- Update to 1.D8
- Remove a patches (solved in upstream):
  * scidavis-0.2.4-documentation.patch
  * scidavis-0.2.4-link.patch
  * scidavis-0.2.4-qassistantclient.patch
  * scidavis-0.2.4-undefined_operation.patch
- Update a patches:
  * scidavis.1.D8_correct_return.patch
  * scidavis.1.D8_graph_const.patch
- Comment for the line include( ../python.pri ):
  * add scidavis.1.D8_comment_python.patch
- Used a package from openSUSE instead of a static library:
  * add scidavis.1.D8_not_orig_liborigin.patch
- Add BuildRequires: cmake boost-devel liborigin2-devel
- Add binary readWriteProject file
- Updated manual page
* Wed Oct 29 2014 avvissu@yandex.ru
- Fix for 64bit build
* Mon Mar 25 2013 joop.boonen@opensuse.org
- Added BuildRequires: glu-devel as it's not a
  BuildRequirement for Mesa-devel anymore for openSUSE > 12.2
- The package name of libqwtplot3d-devel has been
  changed to qwtplot3d-devel
* Tue Aug 28 2012 scorot@free.fr
- fix build on recent product with patch5
* Tue Feb 21 2012 lars@linux-schulserver.de
- run spec-cleaner
- splitted out separate changes file
- added the following patches:
  + scidavis-0.2.4-undefined_operation.patch
  + scidavis-0.2.4-graph_const.patch
  + scidavis-0.2.4-correct_return.patch
  + scidavis-0.2.4-documentation.patch
- build parallel
- compile with optflags
* Thu Oct 28 2010 Leon Freitag <leon@links2linux.de>
- update to version 0.2.4, official 0.2.4 changelog:
  Most important changes since 0.2.3:
- Some parts of the Python API have been marked as deprecated and generate warnings when used. This
  may be a bit unusual for a bugfix release; on the other hand, they won't be removed any time soon
  and inserting the deprecation warnings now will give everyone as much time as possible for getting
  accustomed to the API we're moving towards.
  Most prominently,
    Table.cell(column,row) and
    Table.setCell(column,row,value)
  are deprecated in favour of
    Table.column(column - 1).valueAt(row - 1) and
    Table.column(column - 1).setValueAt(row - 1, value)
  (note that the column/row INDICES DIFFER BY ONE!); the same goes for
    Table.text(c,r) -> Table.column(c - 1).textAt(r - 1) and
    Table.setText(c,r,text) -> Table.column(c - 1).setTextAt(r - 1,text).
  This serves multiple purposes. It simplifies the interfaces by grouping all functionality specific
  to a certain column in the Column class; it allows column objects to be stored and passed around;
  and it moves from the unconventional 1-based indexing to the more conventional 0-based indexing.
  Future additions to the API will increasingly make use of the columns-as-objects paradigm.
- lots of bugfixes, again including crashes
- fixed compatibility issues with Qt 4.6 and SIP 4.9
- performance improvements
- substantially improved support for plots involving date/time data
- added two Czech translations: a default one by Pavel Fric (feedback requested via
  http://fripohled.blogspot.com) and an alternative one by Jan Helebrant
- updated Spanish translation, thanks to Mauricio Troviano; Brazilian Portuguese translation, thanks
  to Fellyp do Nascimento; and German translation
- fixed and extended many parts of the API for Python scripts, including the new methods
    Layer.pickPoint()
    MDIWindow.clone()
    Folder.save(filename)
    newGraph(string)
    Layer.printDialog()
    Graph.printDialog()
    Layer.setRightTitle(string)
    Layer.setTopTitle(string)
    Layer.grid() # => returns an instance of the new class Grid
    Layer.insertFunctionCurve(formula,from=0,to=1,points=100,title="")
    Layer.insertPolarCurve(radial_formula,angular_formula,from=0,to=2*pi,parameter="t",points=100,title="")
    Layer.insertParametricCurve(x_formal,y_formula,from=0,to=1,parameter="t",points=100,title="")
    Matrix.recalculate()
  the constants QwtPlot.yLeft, QwtPlot.yRight, QwtPlot.xBottom,
  QwtPlot.xTop for specifying axes and the Grid class
- multiple graphs can have active tools simultaneously
- based on user feedback, the default behaviour when importing ASCII
  files has been changed to interpret the data as numeric (only applies
  to fresh installations of SciDAVis)
- automatic resizing of table rows for multi-line cells intentionally
  dropped, because this seems to be rarely needed and has a huge impact
  on performance for large tables
  For older changes, see the CHANGES file in the documentation.
* Thu Mar 26 2009 Leon Freitag <leon@links2linux.de>
- update to version 0.2.1, official 0.2.1 changelog:
  This is the first bugfix release in the 0.2 series. Most importantly,
  saving project files containing fit/function curves works again.
  Other fixes include:
  - fixed opening of backup copy on discovery of a corrupt project file
  - Spanish translation update by Mauricio Troviano
  - fixed several regressions introduced by the table/matrix rewrites in 0.2.0
  - added per mille and per ten thousand signs to SymbolDialog
  - compatibility problems between SIP versions triggers a warning instead
  of a crash (happens sometimes when SIP version at runtime differs from
  the one  used at compile time)
  Changes from 0.1.4 to 0.2.0:
  Most important changes (since 0.1.4)
  - multi-level undo/redo for all operations on tables and matrices
  - many operations on tables and matrices now support non-contiguous selections
  - the important options/controls for matrices and tables are now integrated in a sidebar
  of control tabs which make working with column or matrix based data much more
  convenient (almost no more opening and closing of dialogs necessary)
  - tables now support different formulas for each cell
  - numeric values are now stored independent of their textual representation,
  i.e., you don't lose data when hiding decimal digits
  - formula edit mode: tables feature a new mode which allows the user to
  individually edit the formula for each cell
  - invalid cells: tables now mark cells without input as invalid rather
  than treating them as 0; these cells are ignored in plots
  - date/time values are now internally stored as QDateTime objects which
  opens up many new possibilities of date/time manipulation using
  PyQt/Python scripting
  - many bug fixes
* Sun May  4 2008 Leon Freitag <leon@links2linux.de>
- moved the manual to /usr/share/doc/packages/scidavis-manual
- updated to version 0.1.3, official 0.1.3 changelog:
  Most important changes (since 0.1.2)
  - page orientation for PDF/EPS export can now be chosen manually
  - executing script code now gives a visual feedback
  - new Windows installer
  - many improvements to make compilation and Linux packaging easier
  - fixed graph duplication
  - fixed unnecessary graph rescaling
  - several other bugs fixed
* Tue Aug  7 2007 Quentin Denis <quentin@links2linux.de>
- initial package for SUSE
